==> haskell-integer-conversion-0.1.1-53-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-integer-conversion.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 integer-conversion
version:              0.1.1
visibility:           public
id:                   integer-conversion-0.1.1-I4hhxh6gajl1H3JbHPJKoN
key:                  integer-conversion-0.1.1-I4hhxh6gajl1H3JbHPJKoN
license:              BSD-3-Clause
copyright:            (c) 2023 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/integer-conversion
synopsis:             Conversion from strings to Integer
description:
    The naive @foldl'\'' (\acc d -> acc * 10 + d) 0@ is expensive (quadratic!) for large @Integer@s.
    This package provides sub-quadratic implementation.

category:             Data
abi:                  746c37dc34f41d1e43dd3fcb356f6e1a
exposed:              True
exposed-modules:      Data.Integer.Conversion
import-dirs:          /usr/lib/ghc-9.6.6/site-local/integer-conversion-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/integer-conversion-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/integer-conversion-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-integer-conversion
hs-libraries:         HSinteger-conversion-0.1.1-I4hhxh6gajl1H3JbHPJKoN
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    primitive-0.9.1.0-LZUymL07sjCJKODqCvDEyu text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-integer-conversion/html/integer-conversion.haddock

haddock-html:         /usr/share/doc/haskell-integer-conversion/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-integer-conversion-0.1.1-54-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-integer-conversion.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 integer-conversion
version:              0.1.1
visibility:           public
id:                   integer-conversion-0.1.1-5haeWihjZQtFSf48SraST8
key:                  integer-conversion-0.1.1-5haeWihjZQtFSf48SraST8
license:              BSD-3-Clause
copyright:            (c) 2023 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/integer-conversion
synopsis:             Conversion from strings to Integer
description:
    The naive @foldl'\'' (\acc d -> acc * 10 + d) 0@ is expensive (quadratic!) for large @Integer@s.
    This package provides sub-quadratic implementation.

category:             Data
abi:                  d7d2230264afa07274d6373afafed04e
exposed:              True
exposed-modules:      Data.Integer.Conversion
import-dirs:          /usr/lib/ghc-9.6.6/site-local/integer-conversion-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/integer-conversion-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/integer-conversion-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-integer-conversion
hs-libraries:         HSinteger-conversion-0.1.1-5haeWihjZQtFSf48SraST8
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    primitive-0.9.1.0-6uX3awsflEb6ebVZsasp0o text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-integer-conversion/html/integer-conversion.haddock

haddock-html:         /usr/share/doc/haskell-integer-conversion/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
